<div align="center">
  <br><img align="center" height="200" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/install/hiphp.png" alt="hiphp by yasserbdj96">
  <h1>Hiphp</h1>
  <strong>Free & Open source project for create a BackDoor to control PHP-based sites.</strong>
</div>
<br>

[![Test on Ubuntu latest](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-linux.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-linux.yml)
[![Test on Windows latest](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-win.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-win.yml)
[![Test on MacOS latest](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-mac.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/python-app-on-mac.yml)
[![Test requirements windows](https://github.com/yasserbdj96/hiphp/actions/workflows/test-requirements-win.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/test-requirements-win.yml)
[![Test requirements linux](https://github.com/yasserbdj96/hiphp/actions/workflows/test-requirements-linux.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/test-requirements-linux.yml)
[![pypi-setup](https://github.com/yasserbdj96/hiphp/actions/workflows/pypi-setup.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/pypi-setup.yml)
[![Docker image](https://github.com/yasserbdj96/hiphp/actions/workflows/docker-image.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/docker-image.yml)
[![Github Container Registry](https://github.com/yasserbdj96/hiphp/actions/workflows/gcr.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/gcr.yml)
[![Upload to PYPI](https://github.com/yasserbdj96/hiphp/actions/workflows/pipup.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/pipup.yml)
[![ubuntu install](https://github.com/yasserbdj96/hiphp/actions/workflows/ubuntu-install.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/ubuntu-install.yml)
[![Deploy static content to Pages](https://github.com/yasserbdj96/hiphp/actions/workflows/pages.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/pages.yml)
[![CodeQL](https://github.com/yasserbdj96/hiphp/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/yasserbdj96/hiphp/actions/workflows/codeql-analysis.yml)
[![CodeFactor](https://www.codefactor.io/repository/github/yasserbdj96/hiphp/badge)](https://www.codefactor.io/repository/github/yasserbdj96/hiphp)
[![Supported Versions](https://img.shields.io/pypi/pyversions/hiphp.svg)](https://pypi.org/project/hiphp) 
[![Visitors](https://visitor-badge.laobi.icu/badge?page_id=yasserbdj96.hiphp&format=true)](https://github.com/yasserbdj96/hiphp)
[![Docker pulls](https://img.shields.io/docker/pulls/yasserbdj96/hiphp)](https://hub.docker.com/r/yasserbdj96/hiphp/)
[![Open Source](https://img.shields.io/badge/Open%20Source-%E2%99%A5-red)](https://github.com/yasserbdj96/hiphp)
[![Stars](https://img.shields.io/github/stars/yasserbdj96/hiphp?color=red)](https://github.com/yasserbdj96/hiphp)
[![Forks](https://img.shields.io/github/forks/yasserbdj96/hiphp?color=red)](https://github.com/yasserbdj96/hiphp)
[![Watching](https://img.shields.io/github/watchers/yasserbdj96/hiphp?label=Watchers&color=red&style=flat-square)](https://github.com/yasserbdj96/hiphp)
![GitHub contributors](https://img.shields.io/github/contributors/yasserbdj96/hiphp)
![GitHub closed issues](https://img.shields.io/github/issues-closed/yasserbdj96/hiphp)
![GitHub pull requests](https://img.shields.io/github/issues-pr-raw/yasserbdj96/hiphp)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/yasserbdj96/hiphp)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/yasserbdj96/hiphp)
[![GitHub license](https://img.shields.io/github/license/yasserbdj96/hiphp)](https://github.com/yasserbdj96/hiphp)
[![Join the chat at https://gitter.im/yasserbdj96/hiphp](https://badges.gitter.im/yasserbdj96/hiphp.svg)](https://gitter.im/yasserbdj96/hiphp?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

<br>
<h2>What is Hiphp?</h2>
<p>The BackDoor of HIPHP allows you to control the websites that are based on PHP using HTTP/HTTPS protocol. It works by sending files, tokens, and commands to the site using port 80's POST/GET method. After placing the HIPHP_HOLE_CODE into any PHP file, it will allow you to access it and perform various activities such as downloading and editing files. It also allows you to connect to tor networks, this BackDoor is a password protected.</p>


<br>
<h2>Table of Contents:</h2>

- [What is Hipip?](#what-is-hiphp)
- [Table of Contents](#Table-of-Contents)
- [Demo](#Demo)
- [How do you use this version of the project?](#How-do-you-use-this-version-of-the-project)
- [All languages used in this project](#All-languages-used-in-this-project)
- [Where can you find this project?](#Where-can-you-find-this-project)
- [Requirements](#Requirements)
    - [used requirements](#used-requirements)
    - [Install all Requirements](#Install-all-Requirements)
- [Supported Distributions](#Supported-Distributions)
- [Hiphp with Docker](#Hiphp-with-Docker)
    - [Docker pull build and run](#Docker-pull-build-and-run)
    - [Docker Hub pull build and run](#Docker-Hub-pull-build-and-run)
    - [GitHub container registry pull build and run](#GitHub-container-registry-pull-build-and-run)
- [Installation](#Installation)
    - [Python Package Installation](#Python-Package-Installation)
    - [Ubuntu Installation](#Ubuntu-Installation)
    - [Termux Installation](#Termux-Installation)
- [Run without installation](#Run-without-installation)
    - [Run with hiphp-cli](#Run-with-hiphp-cli)
        - [Help for hiphp-cli](#help-for-hiphp-cli)
    - [Run with hiphp-desktop](#Run-with-hiphp-desktop)
    - [Run with hiphp-tk](#Run-with-hiphp-tk)
- [Use hiphp As Script](#Use-As-Script)
    - [Script Usage](#Script-Usage)
    - [Script Examples](#Script-Examples)
- [HIPHP_HOLE_CODE Example](#HIPHP_HOLE_CODE-Example)
- [Screenshots](#Screenshots)
- [Changelog History](#Changelog-History)
- [Limitations](#Limitations)
- [Development By](#Development-By)
- [License](#License)
- [Support](#Support)


<br>
<h2>Demo:</h2>
<div align="center">
    <!--a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/hiphp_cli.gif">
        <img src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/hiphp_cli.gif" alt="hiphp by yasserbdj96">
    </a-->
    <a href="https://asciinema.org/a/523450" target="_blank"><img src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/demo.png" /></a>
</div>

<br>
<h2>How do you use this version of the project?</h2>
[✓] Command Line Interface (CLI).<br>
[✓] Graphical User Interface (GUI).<br>
[✓] Python Package.<br>
[✓] Script.<br>
[✓] Docker Container.

<br>
<h2>All languages used in this project:</h2>
* Python3<br>
* PHP<br>
* Shell (Bash)<br>
* Shell (Batch)<br>
* JavaScript<br>
* CSS<br>
* HTML

<br>
<h2>Where can you find this project?</h2>
[✓] <a href="https://pypi.org/project/hiphp">https://pypi.org/project/hiphp/</a><br>
[✓] <a href="https://hub.docker.com/r/yasserbdj96/hiphp">https://hub.docker.com/r/yasserbdj96/hiphp</a><br>
[✓] <a href="https://github.com/yasserbdj96/hiphp">https://github.com/yasserbdj96/hiphp</a><br>
[✓] <a href="https://github.com/yasserbdj96/hiphp/pkgs/container/hiphp">Github Packages</a><br>

<br>
<h2>Requirements</h2>
<h4>used requirements:</h4>
<!--[✓] <a href="https://github.com/yasserbdj96/ashar">ashar</a><br-->
[✓] <a href="https://pypi.org/project/requests/">requests</a><br>
[✓] <a href="https://pypi.org/project/hexor/">hexor</a><br>
[✓] <a href="https://pypi.org/project/biglibrary/">biglibrary</a><br>
[✓] <a href="">tk</a><br>
[✓] <a href="https://pypi.org/project/Eel/">eel</a><br>
[✓] <a href="https://pypi.org/project/readline/">readline</a><br>
[✓] <a href="https://pypi.org/project/chardet/">chardet</a>

<br>
<h4>Install all Requirements:</h4>

```bash
# For Linux:
❯ bash install_all_requirements_linux.sh

# For Windows:
# Do not forget to modify the "config.ini" file or use the following command:
# > python -c "import sys; open('config.ini','w+').write('python_default_path='+sys.executable)"
# OR Run 'configure-config-file-for-windows.py'.
❯ install_all_requirements_win.bat
```

<br>
<h2>Supported Distributions:</h2>

| Distribution   | Version Check | Python Version | Installation | hiphp-cli  | hiphp-desktop | hiphp-tk |
| :------------: | :-----------: | :------------: | :----------: | :--------: | :-----------: | :------: |
| Ubuntu         | Last version  | 3.6 --> 3.10   | ✓            |  ✓         | ✓             | ✓        |
| Windwos        | Last version  | 3.6 --> 3.10   | ✗            |  ✓         | ✓             | ✓        |
| MacOS          | Last version  | 3.6 --> 3.10   | ✗            |  ✓         | ✓             | ✓        |
| Android-termux | Last version  | 3.6 --> 3.10   | ✓            |  ✓         | ✗             | ✗        |
| Nethunter      | Last version  | 3.6 --> 3.10   | ✓            |  ✓         | ✗             | ✓        |

<br>
<h2>Hiphp with Docker:</h2>
<h4>Docker pull build and run:</h4>

```bash
# Build:
❯ docker build -t hiphp:latest .

# Run as CLI:
❯ docker run -e KEY="<KEY>" -e URL="<URL>" -i -t hiphp:latest

# Run as GUI:
❯ docker run -e DST="True" -d --rm -p 127.0.0.1:8080:8080 -i -t hiphp:latest
```

<h4>Docker Hub pull build and run:</h4>

```bash
# Pull:
❯ docker pull yasserbdj96/hiphp:latest

# Build:
❯ docker build -t docker.io/yasserbdj96/hiphp:latest .

# Run as CLI:
❯ docker run -e KEY="<KEY>" -e URL="<URL>" -i -t docker.io/yasserbdj96/hiphp:latest

# Run as GUI:
❯ docker run -e DST="True" -d --rm -p 127.0.0.1:8080:8080 -i -t docker.io/yasserbdj96/hiphp:latest
```

<h4>GitHub container registry pull build and run:</h4>

```bash
# Pull:
❯ docker pull ghcr.io/yasserbdj96/hiphp:latest

# Build:
❯ docker build -t ghcr.io/yasserbdj96/hiphp:latest .

# Run as CLI:
❯ docker run -e KEY="<KEY>" -e URL="<URL>" -i -t ghcr.io/yasserbdj96/hiphp:latest

# Run as GUI:
❯ docker run -e DST="True" -d --rm -p 127.0.0.1:8080:8080 -i -t ghcr.io/yasserbdj96/hiphp:latest
```
<br>
<h2>Installation:</h2>
<h4>Python Package Installation:</h4>

```bash
# Install from pypi:
❯ pip install hiphp
# OR
❯ python -m pip install hiphp

# Local install:
❯ git clone https://github.com/yasserbdj96/hiphp.git
❯ cd hiphp
❯ pip install -r requirements-pypi.txt
❯ sudo python setup.py install

# Uninstall:
❯ pip uninstall hiphp
```

<h4>Ubuntu Installation:</h4>

```bash
# Dwonload:
❯ git clone https://github.com/yasserbdj96/hiphp.git

# Go to Installation folder:
❯ cd hiphp/install

# Install:
❯ bash install.sh -i
❯ hiphp

# Update:
❯ bash install.sh -up

# Usage:
#      hiphp [OPTION]
#      hiphp --help                --> hiphp cli help.
#      hiphp --geth [KEY] [URL]    --> Get the HIPHP_HOLE_CODE Encrypted by your [KEY].
#      hiphp [KEY] [URL]           --> Connect to the victim's website (CLI) Mode.
#      hiphp --tk                  --> Run hiphp with 'hiphp-tk' (GUI) Mode.
#      hiphp --dst                 --> Run hiphp with 'hiphp-desktop' (GUI) Mode.
#      hiphp --version             --> Get the version number you are working with.

# Uninstall:
❯ bash install.sh -u
```

<h4>Termux Installation:</h4>

```bash
# Dwonload:
❯ git clone https://github.com/yasserbdj96/hiphp.git

# Go to Installation folder:
❯ cd hiphp/install

# Install:
❯ bash install.sh -ti
❯ hiphp

# Update:
❯ bash install.sh -tup

# Usage:
#      hiphp [OPTION]
#      hiphp --help                --> hiphp cli help.
#      hiphp --geth [KEY] [URL]    --> Get the HIPHP_HOLE_CODE Encrypted by your [KEY].
#      hiphp [KEY] [URL]           --> Connect to the victim's website (CLI) Mode.
#      hiphp --version             --> Get the version number you are working with.

# Uninstall:
❯ bash install.sh -tu
```

<br>
<h2>Run without installation:</h2>
<h4>Run with hiphp-cli:</h4>

```bash
# Dwonload:
❯ git clone https://github.com/yasserbdj96/hiphp.git
❯ cd hiphp

# install requirements:
❯ pip install -r requirements.txt
❯ pip install -r requirements-linux.txt #for linux os.
❯ pip install -r requirements-win.txt #for windows os.
# OR
❯ bash install_all_requirements_linux.sh #for linux os.
# OR
❯ install_all_requirements_win.bat #for windows os.

# default run on any os:
❯ python3 run.py <KEY> <URL>

# Run with Makefile:
❯ make run arg="cli" url="<URL>" key="<KEY>"

# For Windows:
# Do not forget to modify the "config.ini" file or use the following command:
# > python -c "import sys; open('config.ini','w+').write('python_default_path='+sys.executable)"
# OR Run 'configure-config-file-for-windows.py'.
❯ run.bat <KEY> <URL>

```

<br>
<h5>Help for hiphp-cli:</h5>

```
hiphp Commands :
════════════════
  Command                            Description
  -------                            -----------
[OPTIONS]

  --help, help                       ─> # Display this help.
  --help [ACTIONS], help [ACTIONS]   ─> # Help for a specific command.
  --geth, geth                       ─> # Get the hole Code, "HIPHP_HOLE_CODE" It has the same purpose.
  --phpinfo, phpinfo                 ─> # Some information about the server.
  --cls, cls                         ─> # Clear console.
  --exit, exit                       ─> # Exit this console.

[ACTIONS]

  --ls, ls                           ─> # List information about the FILEs (the current directory by default).
  Usage: --ls [OPTION] [PATH], ls [OPTION] [PATH]
  Mandatory arguments to long options:
    --ls                             ─> # Get a list of all files and folders from the current directory.
    --ls [PATH]                      ─> # Get a list of all files and folders from a specified directory.
    --ls -all                        ─> # Get a list of all files, folders and subfolders from the current directory.
    --ls -all [PATH]                 ─> # Get a list of all files, folders and subfolders from a specified directory.

  --cat, cat                         ─> # Concatenate FILE to standard output.
  Usage: --cat [FILE_PATH]

  --set, set                         ─> # Create a code that is always saved on during work.
  Usage: --set [PHP_CODE]
  You can return the initial value with "--dset" or "dset".

  --cd, cd                           ─> # Change directory.
  Usage: --cd [PATH]

  --rf, rf, run                      ─> # Run code from file.
  Usage: --rf [FILE_PATH] [VARIABLES]
  Mandatory arguments to long options:
    --rf [FILE_PATH]                 ─> # Run code from file.
    --rf [FILE_PATH] [VARIABLES]     ─> # Run code from file with variables, EX: --rf example.php var==hello
  
  --up, up, upload                   ─> # Upload a file.
  Usage: --up [FILE_PATH] [PATH]
  Mandatory arguments to long options:
    --up [FILE_PATH]                 ─> # Upload a file to the current directory.
    --up [FILE_PATH] [PATH]          ─> # Upload a file to a specified directory.

  --down, down, download             ─> # download a file.
  Usage: --down [-f/-d] [FILE/DIR_PATH] [OUT_PATH]
  Mandatory arguments to long options:
    --down -f [FILE_PATH]            ─> # Download a file to the current directory.
    --down -f [FILE_PATH] [OUT_PATH] ─> # Download file to a specified directory.
    --down -d [DIR_PATH]             ─> # Download a folder to the current directory.
    --down -d [DIR_PATH] [OUT_PATH]  ─> # Download folder to a specified directory.
    --down -all                      ─> # Download all files to the current directory.
    --down -all [OUT_PATH]           ─> # Download all files to a specified directory.

  --zip, zip                         ─> # Compress a directory.
  Usage: --zip [DIR_PATH]
  Mandatory arguments to long options:
    --zip                            ─> # Compress the current directory.
    --zip [DIR_PATH]                 ─> # Compress a specific directory.

  --edt, edt, edit                   ─> # To edit files.
  Usage: --edt [FILE_PATH]
  Mandatory arguments to long options:
    CTRL+q                           ─> # To exit.
    CTRL+s                           ─> # To save.

  --rm, rm, delete                   ─> # To delete files and folders.
  Usage: --rm [-f/-d] [FILE/DIR_PATH]
  Mandatory arguments to long options:
    --rm -f [FILE_PATH]              ─> # Delete a file.
    --rm -d [DIR_PATH]               ─> # Delete a folder.

[ABOUT]

  --update, update                   ─> # check for updates.
  --license, license                 ─> # This project license.
  --about, about                     ─> # About this project.
  --version, version                 ─> # Get the version number you are working with.
```

<br>
<h4>Run with hiphp-desktop:</h4>

```bash
# Dwonload:
❯ git clone https://github.com/yasserbdj96/hiphp.git
❯ cd hiphp

# install requirements:
❯ pip install -r requirements.txt
❯ pip install -r hiphp-desktop/requirements-dst.txt
❯ pip install -r requirements-linux.txt #for linux os.
❯ pip install -r requirements-win.txt #for windows os.
# OR
❯ bash install_all_requirements_linux.sh #for linux os.
# OR
❯ install_all_requirements_win.bat #for windows os.

# run with hiphp-desktop tool:
❯ cd hiphp-desktop
❯ python3 main.py

# Run with Makefile:
❯ make run arg="dst" url="<URL>" key="<KEY>"

# For Linux:
❯ bash run-hiphp-desktop.sh

# For Windows:
# Do not forget to modify the "config.ini" file or use the following command:
# > python -c "import sys; open('config.ini','w+').write('python_default_path='+sys.executable)"
# OR Run 'configure-config-file-for-windows.py'.
❯ run-hiphp-desktop.bat

```

<br>
<h4>Run with hiphp-tk:</h4>

```bash
# Dwonload:
❯ git clone https://github.com/yasserbdj96/hiphp.git
❯ cd hiphp

# install requirements:
❯ pip install -r requirements.txt
❯ pip install -r hiphp-tk/requirements-tk.txt
❯ pip install -r requirements-linux.txt #for linux os.
❯ pip install -r requirements-win.txt #for windows os.
# OR
❯ bash install_all_requirements_linux.sh #for linux os.
# OR
❯ install_all_requirements_win.bat #for windows os.

# run with hiphp-tk tool:
❯ cd hiphp-tk
❯ python3 main.py

# Run with Makefile:
❯ make run arg="tk" url="<URL>" key="<KEY>"

# For Linux:
❯ bash run-hiphp-tk.sh

# For Windows:
# Do not forget to modify the "config.ini" file or use the following command:
# > python -c "import sys; open('config.ini','w+').write('python_default_path='+sys.executable)"
# OR Run 'configure-config-file-for-windows.py'.
❯ run-hiphp-tk.bat

```

<br>
<h2>Use hiphp As Script:</h2>
<h4>Script Usage:</h4>

```python
from hiphp import *

# Connect:
p1=hiphp(key="<KEY>",url="<URL>")
```

<h4>Script Examples:</h4>

```python
#START{
from hiphp import *

# Connect:
p1=hiphp(key="123",url="http://127.0.0.1/index.php")#Default: retu=False.
#p1=hiphp(key="123",url="http://kfdjlkgjflkgjdfkjgkfdjgkjdfkgjk.onion/index.php")
#p1=hiphp(key="123",url="https://google.com/index.php")

# Get the hole Code:
p1.get_hole()# Copy this code into the file whose path you entered earlier. ex: https://localhost/index.php

# Example:1
# Command:
p1.run("echo 'this is a test';")

# Example:2
# Run code from file:
p1.run_file("./examples.php")# Run code from file.
p1.run_file("./examples.php","var1==true","var2==hiii")# Run code from file With the entry of variables.

# Example:3
# Upload a file:
p1.upload("./examples.php")# Upload a file to the current directory.
p1.upload("./examples.php","./upload_path/")# Upload a file to a specific directory.

# Example:4
# Compress a path:
p1.compress()# Compress the current directory.
p1.compress("./example/")# Compress a specific directory.

# Example:5
# download a file:
p1.download("example.zip")# download a specific file to the current directory.
p1.download("example.zip","<OUT_PATH>")# download a specific file to specific directory.

# Example:6
# Command line interface:
p1.cli()
#}END.
```

<br>
<h2>HIPHP_HOLE_CODE Example:</h2>
<div align="center">
    <img src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/HIPHP_HOLE_CODE.png" alt="hiphp by yasserbdj96">
</div>

<br>
<h2>Screenshots:</h2>

<div align="center">
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot.png" alt="hiphp Social preview">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot0.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot0.png" alt="hiphp-cli on linux">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot1.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot1.png" alt="hiphp-cli help">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot2.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot2.png" alt="hiphp-cli installed on linux">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot3.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot3.png" alt="hiphp-cli installed on termux">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot4.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot4.png" alt="hiphp-cli on windows">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot14.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot14.png" alt="hiphp-cli scanning">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot5.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot5.png" alt="hhiphp-desktop login">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot6.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot6.png" alt="hiphp-desktop">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot7.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot7.png" alt="hiphp-desktop editor">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot8.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot8.png" alt="hiphp-desktop login dark mode">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot9.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot9.png" alt="hiphp-desktop dark mode">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot10.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot10.png" alt="hiphp-desktop editor dark mode">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot11.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot11.png" alt="hiphp-desktop settings">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot12.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot12.png" alt="hiphp-tk login">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot13.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot13.png" alt="hiphp-tk">
    </a>
    <a href="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot15.png">
        <img height="100" src="https://raw.githubusercontent.com/yasserbdj96/hiphp/main/screenshot/screenshot15.png" alt="hiphp after installed on linux">
    </a>
</div>

<br>
<h2>Changelog History:</h2>

<details>
  <summary>Click to See changelog History</summary>

```
## 0.2.33 [05-12-2022][Last Version]
 - Bug fixes & performance improvements.

## 0.2.32 [05-12-2022]
 - Update template in "hiphp-desktop".
 - Update documents.
 - Bug fixes & performance improvements.

## 0.2.31 [27-11-2022]
 - Add PWA (Service Worker) to "hiphp-desktop".
 - Updated installation options.
 - Update site files.
 - Add PWA installer as an option to settings in "hiphp-desktop".
 - Fix Dark Mode option.
 - Fix File Creation, Modification and Access Date in "hiphp-desktop".
 - Add a multiple selector in "hiphp-desktop".
 - Fix running on Windows.
 - Activate the arrow feature to return to previous commands (only for Linux).
 - Add login window on "hiphp-tk".
 - Update List information about the FILEs "hiphp-cli".
 - Bug fixes & performance improvements.

## 0.2.30 [02-11-2022]
 - Fix auto login in "hiphp-desktop".
 - Fix file info in "hiphp-desktop".
 - Add Dark Mode option to settings in "hiphp-desktop".
 - Add "--edt" command to edit files.
 - Fix "--down" command.
 - Fix default slash on windows server.
 - Change name of archive files.
 - Add "--rm" command to Delete files and folders.
 - Add a full site extractor to find HIPHP_HOLE_CODE.
 - Fix "hiphp --help" command.
 - Improve some commands.
 - Bug fixes & performance improvements.

## 0.2.29 [13-10-2022]
 - Add the ability to install hiphp on termux Android.
 - Add "--version" command.
 - Add Dark Mode template to "hiphp-desktop".
 - Bug fixes & performance improvements.

## 0.2.28 [27-09-2022]
 - Add "font-awesome" to "php-desktop".
 - Add icons to "php-desktop".
 - Add auto login to "php-desktop".
 - Add file information to "php-desktop".
 - Add line numbering to textarea editor in "php-desktop".
 - Fix "hiphp --dst" & "hiphp --tk" after installation on Ubuntu.
 - Bug fixes & performance improvements.

## 0.2.27 [13-09-2022]
 - Updated some CLI Errors messages.
 - Updated CLI logo.
 - Delete unused codes.
 - Upgrading "php-desktop" in order to avoid errors that occur with various systems.
 - Bug fixes & performance improvements.

## 0.2.26 [07-09-2022]
 - Upgraded Docker files in order to be able to work from outside the container.
 - Add download option in "hiphp_desktop".
 - Bug fixes & performance improvements.

## 0.2.25 [03-09-2022]
 - Fix "--down" command on windows os.
 - Color correction in the command line interface on windows os.
 - Bug fixes & performance improvements.

## 0.2.24 [28-08-2022]
 - Fix "hiphp --ftp"
 - Add "--cd" command for Change directory.
 - Update all commands from "--command" to "command" (You can use both).
 - Update & fix bugs in "hiphp --dst".
 - Update help menu.
 - Bug fixes & performance improvements.

## 0.2.23 [22-08-2022]
 - Fix the entry with uppercase and lowercase letters.
 - Add "--down" command for Download files & folders.
 - Add "--zip" command for Compress files & folders.
 - Update "--help" to "--help [ACTION]".
 - Update the help list and enable it to display help when something goes wrong.
 - Bug fixes & performance improvements.

## 0.2.22 [20-08-2022]
 - Update some info on pypi.
 - Fix "setup.py" windows os.
 - Bug fixes & performance improvements.

## 0.2.21 [18-08-2022]
 - Add "--update" command for check updates.
 - Add "--phpinfo" command for check some server informations.
 - Fix not being able to install internally on Nethunter.
 - Fix some issues in uploading files.
 - Bug fixes & performance improvements.

## 0.2.20 [10-08-2022]
 - Change the display of files in the command "--ls"
 - Fix "HIPHP_HOLE_CODE".
 - Add "--cls" command to clear console.
 - Slight change to the command line interface logo.
 - Bug fixes & performance improvements.

## 0.2.19 [30-07-2022]
 - Preparing for the new version.
 - Rework the software rights with the addition of the Bitcoin wallet address.
 - new logo design.
 - Bug fixes & performance improvements.

## 0.2.18 [06-07-2022]
 - Bug fixes & performance improvements.

## 0.2.17 [03-07-2022]
 - Bug fixes on windows os.

## 0.2.16 [02-07-2022][Version cancelled]
 - Bug fixes & performance improvements.

## 0.2.15 [22-06-2022][Version cancelled]
 - New build.
 - More stability.
 - Command interface update.
 - More commands.
 - Giving access to .onion sites.
 - help menu update.
 - Bug fixes & performance improvements.

## 0.1.14 [06-11-2021][Version cancelled]
 - help menu update.
 - Bug fixes & performance improvements.

## 0.1.13 [09-11-2021][Version cancelled]
 - Safety upgrade.
 - Bug fixes & performance improvements.

## 0.1.12 [09-11-2021][Version cancelled]
 - Safety upgrade.
 - Bug fixes & performance improvements.

## 0.1.11 [03-11-2021][Version cancelled]
 - Command interface update.
 - Bug fixes & performance improvements.

## 0.1.10 [26-07-2021][Version cancelled]
 - Fix Bugs.

## 0.1.9 [07-06-2021][Version cancelled]
 - fix bugs.

## 0.1.8 [2021][Version cancelled]
 - Fix bugs.

## 0.1.7 [04-06-2021][Version cancelled]
 - fix bugs.

## 0.1.6 [04-06-2021][Version cancelled]
 - fix bugs.
 - add upload to upload any file.
 - Simplify the use of the program.

## 0.1.5 [26-05-2021][Version cancelled]
 - fix bugs.

## 0.1.4 [15-05-2021][Version cancelled]
 - fix bugs.
 - new build.

## 0.1.3 [12-05-2021][Version cancelled]
 - Fix bugs.

## 0.1.2 [10-05-2021][Version cancelled]
 - Fix bugs.

## 0.1.1 [06-05-2021][Version cancelled]
 - Import pakages by pipincluder.
 - Fix bugs.

## 0.1.0 [18-04-2021][Version cancelled]
 - New build.
 - Fix bugs.

## 0.0.4 [06-04-2021][Version cancelled]
 - Fix bugs.

## 0.0.3 [06-04-2021][Version cancelled]
 - Fix bugs.

## 0.0.2 [05-04-2021][Version cancelled]
 - Fix bugs.
 - Add help list.
 - Add Executing from files.

## 0.0.1 [05-04-2021][Version cancelled]
 - First public release.
```

</details>

<br>
<h2>Limitations:</h2>
1. When you use hiphp for the first time on a site, the code HIPHP_HOLE_CODE will show you, copy it and upload it to the path you want to connect to, for example 'https://localhost/inc/example.php'.<br>
2. In order for hiphp to work well and without errors, HIPHP_HOLE_CODE must be placed at the top of the target file.<br>
3. hiphp will not work and it will show you a message stating that you are unable to connect to the site if you do not enter the correct path to the location of HIPHP_HOLE_CODE via the link.<br>
4. If you use hiphp on .onion sites, you must run tor services or tor browser.<br>
5. If you are a Windows user, you must modify the "config.ini" file.<br>
6. I AM NOT RESPONSIBLE HOW YOU USE MY TOOLS/PROGRAMS/PROJECTS. BE LEGAL AND NOT STUPID.

<br>
<h2>Development By:</h2>

Developer / Author: [yasserbdj96](https://github.com/yasserbdj96)

<br>
<h2>License:</h2>

<p>Copyright © 2008->Present, yasserbdj96 (Boudjada Yasser)
<br>
The content of this repository is bound by the following license:</p>

<details>
  <summary>Click to See Apache-2.0 license</summary>

```
                                 Apache License
                           Version 2.0, January 2004
                        http://www.apache.org/licenses/

   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

   1. Definitions.

      "License" shall mean the terms and conditions for use, reproduction,
      and distribution as defined by Sections 1 through 9 of this document.

      "Licensor" shall mean the copyright owner or entity authorized by
      the copyright owner that is granting the License.

      "Legal Entity" shall mean the union of the acting entity and all
      other entities that control, are controlled by, or are under common
      control with that entity. For the purposes of this definition,
      "control" means (i) the power, direct or indirect, to cause the
      direction or management of such entity, whether by contract or
      otherwise, or (ii) ownership of fifty percent (50%) or more of the
      outstanding shares, or (iii) beneficial ownership of such entity.

      "You" (or "Your") shall mean an individual or Legal Entity
      exercising permissions granted by this License.

      "Source" form shall mean the preferred form for making modifications,
      including but not limited to software source code, documentation
      source, and configuration files.

      "Object" form shall mean any form resulting from mechanical
      transformation or translation of a Source form, including but
      not limited to compiled object code, generated documentation,
      and conversions to other media types.

      "Work" shall mean the work of authorship, whether in Source or
      Object form, made available under the License, as indicated by a
      copyright notice that is included in or attached to the work
      (an example is provided in the Appendix below).

      "Derivative Works" shall mean any work, whether in Source or Object
      form, that is based on (or derived from) the Work and for which the
      editorial revisions, annotations, elaborations, or other modifications
      represent, as a whole, an original work of authorship. For the purposes
      of this License, Derivative Works shall not include works that remain
      separable from, or merely link (or bind by name) to the interfaces of,
      the Work and Derivative Works thereof.

      "Contribution" shall mean any work of authorship, including
      the original version of the Work and any modifications or additions
      to that Work or Derivative Works thereof, that is intentionally
      submitted to Licensor for inclusion in the Work by the copyright owner
      or by an individual or Legal Entity authorized to submit on behalf of
      the copyright owner. For the purposes of this definition, "submitted"
      means any form of electronic, verbal, or written communication sent
      to the Licensor or its representatives, including but not limited to
      communication on electronic mailing lists, source code control systems,
      and issue tracking systems that are managed by, or on behalf of, the
      Licensor for the purpose of discussing and improving the Work, but
      excluding communication that is conspicuously marked or otherwise
      designated in writing by the copyright owner as "Not a Contribution."

      "Contributor" shall mean Licensor and any individual or Legal Entity
      on behalf of whom a Contribution has been received by Licensor and
      subsequently incorporated within the Work.

   2. Grant of Copyright License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      copyright license to reproduce, prepare Derivative Works of,
      publicly display, publicly perform, sublicense, and distribute the
      Work and such Derivative Works in Source or Object form.

   3. Grant of Patent License. Subject to the terms and conditions of
      this License, each Contributor hereby grants to You a perpetual,
      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
      (except as stated in this section) patent license to make, have made,
      use, offer to sell, sell, import, and otherwise transfer the Work,
      where such license applies only to those patent claims licensable
      by such Contributor that are necessarily infringed by their
      Contribution(s) alone or by combination of their Contribution(s)
      with the Work to which such Contribution(s) was submitted. If You
      institute patent litigation against any entity (including a
      cross-claim or counterclaim in a lawsuit) alleging that the Work
      or a Contribution incorporated within the Work constitutes direct
      or contributory patent infringement, then any patent licenses
      granted to You under this License for that Work shall terminate
      as of the date such litigation is filed.

   4. Redistribution. You may reproduce and distribute copies of the
      Work or Derivative Works thereof in any medium, with or without
      modifications, and in Source or Object form, provided that You
      meet the following conditions:

      (a) You must give any other recipients of the Work or
          Derivative Works a copy of this License; and

      (b) You must cause any modified files to carry prominent notices
          stating that You changed the files; and

      (c) You must retain, in the Source form of any Derivative Works
          that You distribute, all copyright, patent, trademark, and
          attribution notices from the Source form of the Work,
          excluding those notices that do not pertain to any part of
          the Derivative Works; and

      (d) If the Work includes a "NOTICE" text file as part of its
          distribution, then any Derivative Works that You distribute must
          include a readable copy of the attribution notices contained
          within such NOTICE file, excluding those notices that do not
          pertain to any part of the Derivative Works, in at least one
          of the following places: within a NOTICE text file distributed
          as part of the Derivative Works; within the Source form or
          documentation, if provided along with the Derivative Works; or,
          within a display generated by the Derivative Works, if and
          wherever such third-party notices normally appear. The contents
          of the NOTICE file are for informational purposes only and
          do not modify the License. You may add Your own attribution
          notices within Derivative Works that You distribute, alongside
          or as an addendum to the NOTICE text from the Work, provided
          that such additional attribution notices cannot be construed
          as modifying the License.

      You may add Your own copyright statement to Your modifications and
      may provide additional or different license terms and conditions
      for use, reproduction, or distribution of Your modifications, or
      for any such Derivative Works as a whole, provided Your use,
      reproduction, and distribution of the Work otherwise complies with
      the conditions stated in this License.

   5. Submission of Contributions. Unless You explicitly state otherwise,
      any Contribution intentionally submitted for inclusion in the Work
      by You to the Licensor shall be under the terms and conditions of
      this License, without any additional terms or conditions.
      Notwithstanding the above, nothing herein shall supersede or modify
      the terms of any separate license agreement you may have executed
      with Licensor regarding such Contributions.

   6. Trademarks. This License does not grant permission to use the trade
      names, trademarks, service marks, or product names of the Licensor,
      except as required for reasonable and customary use in describing the
      origin of the Work and reproducing the content of the NOTICE file.

   7. Disclaimer of Warranty. Unless required by applicable law or
      agreed to in writing, Licensor provides the Work (and each
      Contributor provides its Contributions) on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied, including, without limitation, any warranties or conditions
      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
      PARTICULAR PURPOSE. You are solely responsible for determining the
      appropriateness of using or redistributing the Work and assume any
      risks associated with Your exercise of permissions under this License.

   8. Limitation of Liability. In no event and under no legal theory,
      whether in tort (including negligence), contract, or otherwise,
      unless required by applicable law (such as deliberate and grossly
      negligent acts) or agreed to in writing, shall any Contributor be
      liable to You for damages, including any direct, indirect, special,
      incidental, or consequential damages of any character arising as a
      result of this License or out of the use or inability to use the
      Work (including but not limited to damages for loss of goodwill,
      work stoppage, computer failure or malfunction, or any and all
      other commercial damages or losses), even if such Contributor
      has been advised of the possibility of such damages.

   9. Accepting Warranty or Additional Liability. While redistributing
      the Work or Derivative Works thereof, You may choose to offer,
      and charge a fee for, acceptance of support, warranty, indemnity,
      or other liability obligations and/or rights consistent with this
      License. However, in accepting such obligations, You may act only
      on Your own behalf and on Your sole responsibility, not on behalf
      of any other Contributor, and only if You agree to indemnify,
      defend, and hold each Contributor harmless for any liability
      incurred by, or claims asserted against, such Contributor by reason
      of your accepting any such warranty or additional liability.

   END OF TERMS AND CONDITIONS

   APPENDIX: How to apply the Apache License to your work.

      To apply the Apache License to your work, attach the following
      boilerplate notice, with the fields enclosed by brackets "[]"
      replaced with your own identifying information. (Don't include
      the brackets!)  The text should be enclosed in the appropriate
      comment syntax for the file format. We also recommend that a
      file or class name and description of purpose be included on the
      same "printed page" as the copyright notice for easier
      identification within third-party archives.

   Copyright © 2008->Present, yasserbdj96 (Boudjada Yasser).

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
```
</details>

<br>
<h2>Support:</h2>
<p>If you like `hiphp` and want to see it improve furthur or want me to create intresting projects , You can buy me a coffee </p>
<div align="center">
    <a href="https://ko-fi.com/yasserbdj96">
        <img src="https://ko-fi.com/img/githubbutton_sm.svg" alt="hiphp by yasserbdj96">
    </a><br>
    BTC: bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9<br>
</div>

<br><br>

<p align="center">
  <samp>
    <a href="https://yasserbdj96.github.io/">website</a> .
    <a href="https://github.com/yasserbdj96">github</a> .
    <a href="https://gitlab.com/yasserbdj96">gitlab</a> .
    <a href="https://www.linkedin.com/in/yasserbdj96">linkedin</a> .
    <a href="https://twitter.com/yasserbdj96">twitter</a> .
    <a href="https://instagram.com/yasserbdj96">instagram</a> .
    <a href="https://www.facebook.com/yasserbdj96">facebook</a> .
    <a href="https://www.youtube.com/@yasserbdj96">youtube</a> .
    <a href="https://pypi.org/user/yasserbdj96">pypi</a> .
    <a href="https://hub.docker.com/u/yasserbdj96">docker</a> .
    <a href="https://t.me/yasserbdj96">telegram</a> .
    <a href="https://gitter.im/yasserbdj96/yasserbdj96">gitter</a> .
    <a href="mailto:yasser.bdj96@gmail.com">e-mail</a> .
    <a href="https://ko-fi.com/yasserbdj96">sponsor</a>
  </samp>
</p>
